/* Test aglet
 */
import com.ibm.aglet.*;
import java.net.URL;

/** This Aglet will go to a specified destination,
  * then will go back home. This is achieved by 2 successive
  * dispatch calls. This is the very simplicity, and may be used
  * to test a remote platform. I used it to see if I could send
  * an agent on Todd's platform, and it did work...
  *
  * @author Ronnie Taib (Ronnie.Taib@crm.mot.com)
  * @version 10/08/99
  */
public class GoThenBack extends Aglet {

    /** home and target addresses
     */
    URL
	home   = null,
	remote = null;
    /** Boolean flags to (simply) know where we are,
      * and what to do next.
      * The aglet will first be local (i.e. local and firstTime
      * are true). Then it goes on the target (i.e. local
      * and firstTime are false). When it goes back, it is
      * local again, but firstTime is false.
      * This should be replaced by a more sophisticated agent,
      * with an Itinerary for example.
      */
    boolean
	local     = true,
	firstTime = true;
    
    /* Initializes the aglet. 
     * Only called the very first time this aglet is created.
     * @param init This agent should be passed the target
     * platform URL as a String in the init variable.
     */
    public void onCreation( Object init ){
	try{
	    remote = new URL( (String)init );
	}
	catch( Exception e ){
	    System.err.println( "Init object is not a valid URL! " );
	    dispose();
	}
	
        // Initialize the variables.
        home = getAgletContext().getHostingURL();

	System.out.println( "I am alive. I will go from " +home
			    +" to " +remote );
    }

    public void run(){
	try{
	    if ( local ){
		if ( firstTime ){
		    local = false;
		    firstTime = false;
		    System.out.println( "Dispatching myself..." );
		    dispatch( remote );
		}
		else{
		    System.out.println( "I am back." );
		    dispose();
		}
	    }
	    else{
		local = true;
/* Uncomment the two following lines if you want your agent to output
 * something on the target platform.
 */
//		System.out.println( "Arriving on the remote platform.\n"
//				    +"Going back now..." );
		dispatch( home );
	    }
	}
	catch( Exception e ){
	    System.err.println( "Could not dispatch, because: ");
	    e.printStackTrace();
	}
    }
} // End GoThenBack
